@@ -56,7 +56,7 @@ I wish to thank the following people for their input:
 
 '''
 
-__version__ = '0.5'
+__version__ = '0.5.1'
 
 import socket
 
@@ -138,12 +138,14 @@ class IP(object):
         self.mask = mask
         self.v = 0
         # Parse input
-        if isinstance(ip, IP):
+        if ip is None:
+            raise ValueError, "Can not pass None"
+        elif isinstance(ip, IP):
             self.ip = ip.ip
             self.dq = ip.dq
             self.v = ip.v
             self.mask = ip.mask
-        elif type(ip) in [int, long]:
+        elif isinstance(ip, (int, long)):
             self.ip = long(ip)
             if self.ip <= 0xffffffff:
                 self.v = version or 4
@@ -164,25 +166,25 @@ class IP(object):
         if self.mask is None:
             self.mask = self.v == 4 and 32 or 128
         # Netmask is numeric CIDR subnet
-        elif type(self.mask) in [int, long] or self.mask.isdigit():
-            self.mask = int(mask)
+        elif isinstance(self.mask, (int, long)) or self.mask.isdigit():
+            self.mask = int(self.mask)
         # Netmask is in subnet notation
         elif isinstance(self.mask, basestring):
-            limit = [32, 128][int(':' in self.mask)]
+            limit = [32, 128][':' in self.mask]
             inverted = ~self._dqtoi(self.mask)
             count = 0
-            while inverted & pow(2, count):
+            while inverted & 2**count:
                 count += 1
             self.mask = (limit - count)
         else:
-            raise ValueError, "Invlid netmask"
+            raise ValueError, "Invalid netmask"
         # Validate subnet size
         if self.v == 6:
             self.dq = self._itodq(self.ip)
-            if self.mask < 0 or self.mask > 128:
+            if not 0 <= self.mask <= 128:
                 raise ValueError, "IPv6 subnet size must be between 0 and 128"
         elif self.v == 4:
-            if self.mask < 0 or self.mask > 32:
+            if not 0 <= self.mask <= 32:
                 raise ValueError, "IPv4 subnet size must be between 0 and 32"
 
     def bin(self):
@@ -283,7 +285,7 @@ class IP(object):
             for h in hx:
                 if len(h) < 4:
                     h = '%04x' % int(h, 16)
-                if 0 > int(h, 16) > 0xffff:
+                if not 0 <= int(h, 16) <= 0xffff:
                     raise ValueError, "%r: IPv6 address invalid: hextets should be between 0x0000 and 0xffff" % dq
                 ip += h
             self.v = 6
@@ -300,7 +302,7 @@ class IP(object):
             if len(q) > 4:
                 raise ValueError, "%r: IPv4 address invalid: more than 4 bytes" % dq
             for x in q:
-                if 0 > int(x) > 255:
+                if not 0 <= int(x) <= 255:
                     raise ValueError, "%r: IPv4 address invalid: bytes should be between 0 and 255" % dq
             while len(q) < 4:
                 q.insert(1, '0')
@@ -358,8 +360,8 @@ class IP(object):
         Return a new <IP> object with a copy of this one.
 
         >>> ip = IP('127.0.0.1')
-        >>> ip.clone()
-        <ipcalc.IP object at 0xb7d4d18c>
+        >>> ip.clone() # doctest: +ELLIPSIS
+        <ipcalc.IP object at 0x...>
         '''
         return IP(self)
 
@@ -531,7 +533,7 @@ class Network(IP):
         '''
         Generate a range of ip addresses within the network.
 
-        >>> for ip in Network('192.168.114.0.40'):
+        >>> for ip in Network('192.168.114.0/30'):
         ...     print str(ip)
         ... 
         192.168.114.0
